@@ -8,7 +8,7 @@ use 5.005;
 use strict;
 use Carp                   ();
 use File::Basename         ();
-use Params::Util           qw(_INSTANCE _INSTANCEDOES);
+use Params::Util 1.05      qw(_INSTANCE _INSTANCEDOES);
 use Email::MIME            ();
 use Email::MIME::Creator   ();
 use Email::Sender::Simple  ();
@@ -380,7 +380,7 @@ Email::Stuffer - A more casual approach to creating and sending Email:: emails
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
